<?php

namespace ArubaFe\Admin\Session;
if (!defined('ABSPATH')) die('No direct access allowed');

class ArubaFeSession
{

    static $session;
    protected $_data;

    public function __construct(){

        if(!session_id())
            session_start();


    }

    public static function getInstance(){
        if(is_null(self::$session))
            self::$session = new self();

        return self::$session;

    }

    /**
     * Init hooks and session data. Extended by child classes.
     *
     * @since 3.3.0
     */
    public function init() {}

    /**
     * Cleanup session data. Extended by child classes.
     */
    public function cleanup_sessions() {
        $_SESSION['ARUBA_FE'] = [];
    }

    /**
     * Magic get method.
     *
     * @param mixed $key Key to get.
     * @return mixed
     */
    public function __get( $key ) {
        return $this->get( $key );
    }

    /**
     * Magic set method.
     *
     * @param mixed $key Key to set.
     * @param mixed $value Value to set.
     */
    public function __set( $key, $value ) {
        $this->set( $key, $value );
    }

    /**
     * Magic isset method.
     *
     * @param mixed $key Key to check.
     * @return bool
     */
    public function __isset( $key ) {
        return isset( $_SESSION['ARUBA_FE'][ sanitize_title( $key ) ] );
    }

    /**
     * Magic unset method.
     *
     * @param mixed $key Key to unset.
     */
    public function __unset( $key ) {

        if ( isset( $_SESSION['ARUBA_FE'][ $key ] ) ) {
            unset( $_SESSION['ARUBA_FE'][ $key ] );
        }
    }

    /**
     * Get a session variable.
     *
     * @param string $key Key to get.
     * @param mixed  $default used if the session variable isn't set.
     * @return array|string value of session variable
     */
    public function get( $key, $default = null ) {

        $key = sanitize_key( $key );

        if(isset( $_SESSION['ARUBA_FE'][ $key ] )){

            $data = wp_kses_post($_SESSION['ARUBA_FE'][ $key ]);

            if(is_serialized($data)){

                return unserialize($data);

            }else{

                return  $data;

            }

        }else{

            return $default;

        }


    }

    /**
     * Set a session variable.
     *
     * @param string $key Key to set.
     * @param mixed  $value Value to set.
     */
    public function set( $key, $value ) {

        if ($value !== $this->get( $key ) ) {
            $_SESSION['ARUBA_FE'][ sanitize_key( $key ) ] = maybe_serialize( $value );
        }
    }


}